@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 import json
 import re
 
@@ -12,14 +14,14 @@ from ..utils import (
 class BandcampIE(InfoExtractor):
     _VALID_URL = r'http://.*?\.bandcamp\.com/track/(?P<title>.*)'
     _TESTS = [{
-        u'url': u'http://youtube-dl.bandcamp.com/track/youtube-dl-test-song',
-        u'file': u'1812978515.mp3',
-        u'md5': u'c557841d5e50261777a6585648adf439',
-        u'info_dict': {
-            u"title": u"youtube-dl  \"'/\\\u00e4\u21ad - youtube-dl test song \"'/\\\u00e4\u21ad",
-            u"duration": 10,
+        'url': 'http://youtube-dl.bandcamp.com/track/youtube-dl-test-song',
+        'file': '1812978515.mp3',
+        'md5': 'c557841d5e50261777a6585648adf439',
+        'info_dict': {
+            "title": "youtube-dl  \"'/\\\u00e4\u21ad - youtube-dl test song \"'/\\\u00e4\u21ad",
+            "duration": 10,
         },
-        u'skip': u'There is a limit of 200 free downloads / month for the test song'
+        '_skip': 'There is a limit of 200 free downloads / month for the test song'
     }]
 
     def _real_extract(self, url):
@@ -58,7 +60,7 @@ class BandcampIE(InfoExtractor):
                     'duration': duration,
                 }
             else:
-                raise ExtractorError(u'No free songs found')
+                raise ExtractorError('No free songs found')
 
         download_link = m_download.group(1)
         video_id = re.search(
@@ -72,9 +74,9 @@ class BandcampIE(InfoExtractor):
                          download_webpage, re.MULTILINE).group(1)
         info = json.loads(info)[0]
         # We pick mp3-320 for now, until format selection can be easily implemented.
-        mp3_info = info[u'downloads'][u'mp3-320']
+        mp3_info = info['downloads']['mp3-320']
         # If we try to use this url it says the link has expired
-        initial_url = mp3_info[u'url']
+        initial_url = mp3_info['url']
         re_url = r'(?P<server>http://(.*?)\.bandcamp\.com)/download/track\?enc=mp3-320&fsig=(?P<fsig>.*?)&id=(?P<id>.*?)&ts=(?P<ts>.*)$'
         m_url = re.match(re_url, initial_url)
         #We build the url we will use to get the final track url
@@ -87,41 +89,41 @@ class BandcampIE(InfoExtractor):
 
         return {
             'id': video_id,
-            'title': info[u'title'],
+            'title': info['title'],
             'ext': 'mp3',
             'vcodec': 'none',
             'url': final_url,
-            'thumbnail': info[u'thumb_url'],
-            'uploader': info[u'artist'],
+            'thumbnail': info['thumb_url'],
+            'uploader': info['artist'],
         }
 
 
 class BandcampAlbumIE(InfoExtractor):
-    IE_NAME = u'Bandcamp:album'
+    IE_NAME = 'Bandcamp:album'
     _VALID_URL = r'http://.*?\.bandcamp\.com/album/(?P<title>.*)'
 
     _TEST = {
-        u'url': u'http://blazo.bandcamp.com/album/jazz-format-mixtape-vol-1',
-        u'playlist': [
+        'url': 'http://blazo.bandcamp.com/album/jazz-format-mixtape-vol-1',
+        'playlist': [
             {
-                u'file': u'1353101989.mp3',
-                u'md5': u'39bc1eded3476e927c724321ddf116cf',
-                u'info_dict': {
-                    u'title': u'Intro',
+                'file': '1353101989.mp3',
+                'md5': '39bc1eded3476e927c724321ddf116cf',
+                'info_dict': {
+                    'title': 'Intro',
                 }
             },
             {
-                u'file': u'38097443.mp3',
-                u'md5': u'1a2c32e2691474643e912cc6cd4bffaa',
-                u'info_dict': {
-                    u'title': u'Kero One - Keep It Alive (Blazo remix)',
+                'file': '38097443.mp3',
+                'md5': '1a2c32e2691474643e912cc6cd4bffaa',
+                'info_dict': {
+                    'title': 'Kero One - Keep It Alive (Blazo remix)',
                 }
             },
         ],
-        u'params': {
-            u'playlistend': 2
+        'params': {
+            'playlistend': 2
         },
-        u'skip': u'Bancamp imposes download limits. See test_playlists:test_bandcamp_album for the playlist test'
+        'skip': 'Bancamp imposes download limits. See test_playlists:test_bandcamp_album for the playlist test'
     }
 
     def _real_extract(self, url):
@@ -130,11 +132,11 @@ class BandcampAlbumIE(InfoExtractor):
         webpage = self._download_webpage(url, title)
         tracks_paths = re.findall(r'<a href="(.*?)" itemprop="url">', webpage)
         if not tracks_paths:
-            raise ExtractorError(u'The page doesn\'t contain any tracks')
+            raise ExtractorError('The page doesn\'t contain any tracks')
         entries = [
             self.url_result(compat_urlparse.urljoin(url, t_path), ie=BandcampIE.ie_key())
             for t_path in tracks_paths]
-        title = self._search_regex(r'album_title : "(.*?)"', webpage, u'title')
+        title = self._search_regex(r'album_title : "(.*?)"', webpage, 'title')
         return {
             '_type': 'playlist',
             'title': title,
